import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = { top: 20, right: 20, left: 20, bottom: 20 };
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const csvUrl =
  'https://gist.githubusercontent.com/minwoopak/07eb41dfcd831afea0847ac77d1d09f5/raw/UN_Population_2019.csv';

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.Population = +d['2020'];
      return d;
    };
    csv(csvUrl, row).then((data) => {
      data = data.slice(0, 10);
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xScale = scaleBand()
    .domain(data.map((d) => d.Country))
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain([0, max(data, (d) => d.Population)])
    .range([0, innerHeight]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left}, ${margin.top})`}>
        {data.map((d) => (
          <rect
            x={xScale(d.Country)}
            y={innerHeight - yScale(d.Population)}
            width={xScale.bandwidth()}
            height={yScale(d.Population)}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
